@@ -1,4 +1,4 @@
-#$Header: /cvsroot/POE-Session-Cascading/lib/POE/Session/Cascading.pm,v 1.9 2002/05/11 23:23:40 matt Exp $
+#$Header: /home/sungo/src/sungo/POE-Session-Cascading/lib/POE/Session/Cascading.pm,v 1.14 2002/08/18 17:50:17 sungo Exp $
 
 # DOCUMENTATION #{{{
 
@@ -12,7 +12,7 @@ Matt Cashner (eek+cpan@eekeek.org)
 
 =head1 DATE
 
-$Date: 2002/05/11 23:23:40 $
+$Date: 2004-04-24 17:03:13 -0400 (Sat, 24 Apr 2004) $
 
 =head1 SYNOPSIS
 
@@ -100,9 +100,9 @@ use strict;
 
 use Carp;
 use POE::Kernel;
-use vars qw($VERSION %STACK %STACKINFO);
+use vars qw(%STACK %STACKINFO);
 
-$VERSION = (qw($Revision: 1.9 $))[1];
+our $VERSION = '1.'.sprintf "%04d", (qw($Rev: 225 $))[1];
 
 # allow users to set the debug flag. also useful for the test suite
 BEGIN {
@@ -268,8 +268,47 @@ sub go {
     $self->{status} = CSC_OK;
 }
 
-sub DESTROY {
+=head2 swap
+    
+    $args{SESSION}->swap($state1, $state2);
+    
+Reorder the event stack. Swap two states in the stack.
+
+=cut
+
+sub swap {
     my $self = shift;
+    my ($state1, $state2) = @_;
+
+    assert(ref $self,'Object integrity');
+    assert($self->{info}, 'Stash integrity');
+    assert(ref $self->{info}, 'Stash referential integrity');
+    assert($self->{stack}, 'Stack integrity');
+    assert(ref $self->{stack}, 'Stack referential integrity');
+
+    
+    return 0 unless $state1 and $state2;
+    
+        
+    my $pos1 = $self->{info}->{$state1};
+    my $pos2 = $self->{info}->{$state2};
+
+    return 0 unless defined $pos1 and defined $pos2;
+    
+    my $temp = $self->{stack}->[$pos1];
+    $self->{stack}->[$pos1] = $self->{stack}->[$pos2];
+    $self->{stack}->[$pos2] = $temp;
+    
+    $self->{info}->{$state1} = $pos2;
+    $self->{info}->{$state2} = $pos1;
+    
+    return 1;
+}
+
+
+sub DESTROY {
+    my $self = shift; 
+    return unless ref $self && $self->{name};
     delete $STACK{$self->{name}};
     delete $STACKINFO{$self->{name}};
 }
@@ -298,8 +337,6 @@ sub _fail_msg {
 
 =over 4
 
-=item * Cannot reorder the stack at runtime
-
 =item * Cannot register or unregister a stack element at runtime
 
 =item * Stack requires outside influence to start (is this actually a problem?)
